.. _examples:

Examples
============

Here is a list of example notebooks to illustrate how to use earthkit-data.


.. toctree::
    :maxdepth: 1
    :caption: Retrieve

    examples/mars.ipynb
    examples/ads.ipynb
    examples/cds.ipynb
    examples/ecmwf_open_data.ipynb
    examples/fdb.ipynb


.. toctree::
    :maxdepth: 1
    :caption: GRIB

    examples/grib_overview.ipynb
    examples/grib_lat_lon_value.ipynb
    examples/grib_metadata.ipynb
    examples/grib_selection.ipynb
    examples/grib_indexing.ipynb
    examples/grib_missing.ipynb
    examples/grib_multi.ipynb
    examples/grib_from_stream.ipynb
    examples/grib_file_pattern.ipynb
    examples/grib_tar.ipynb
    examples/grib_url.ipynb
    examples/grib_to_netcdf.ipynb

.. toctree::
    :maxdepth: 1
    :caption: NetCDF
    :glob:

    examples/netcdf*

.. toctree::
    :maxdepth: 1
    :caption: BUFR
    :glob:

    examples/bufr*

.. toctree::
    :maxdepth: 1
    :caption: ODB
    :glob:

    examples/odb*

.. toctree::
    :maxdepth: 1
    :caption: Other inputs
    :glob:

    examples/from_object.ipynb
    examples/list_of_dict*
    examples/pandas.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Miscellaneous
    :glob:

    examples/settings.ipynb
    examples/cache.ipynb
    examples/projection.ipynb
    examples/metadata.ipynb
    examples/numpy_fieldlist.ipynb
